==> ckmame-2.1.tar.xz: ckmame-2.1/src/MkMameDB.h <==
/*
    MkMameDB.h -- create mamedb
    Copyright (C) 1999-2022 Dieter Baron and Thomas Klausner

    This file is part of ckmame, a program to check rom sets for MAME.
    The authors can be contacted at <ckmame@nih.at>

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions
    are met:
    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in
       the documentation and/or other materials provided with the
       distribution.
    3. The name of the author may not be used to endorse or promote
       products derived from this software without specific prior
       written permission.

    THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
    OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
    ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
    GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
    IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
    OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
    IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef MKMAMEDB_H
#define MKMAMEDB_H

#include "Command.h"
#include "OutputContext.h"

class MkMameDB : public Command {
  public:
    MkMameDB();

    void global_setup(const ParsedCommandline& commandline) override;
    bool execute(const std::vector<std::string>& arguments) override;
    bool global_cleanup() override;

  private:
    std::string dbname, dbname_real;
    std::unordered_set<std::string> exclude;
    std::vector<std::string> file_patterns;
    std::unordered_set<std::string> skip_files;
    DatEntry dat;
    int flags;
    OutputContext::Format fmt;
    std::string detector_name;
    bool force;
    bool runtest;

    bool list_available_dats;
    bool list_dats;
};

#endif // MKMAMEDB_H

==> ckmame-3.0.tar.xz: ckmame-3.0/src/MkMameDB.h <==
/*
    MkMameDB.h -- create mamedb
    Copyright (C) 1999-2022 Dieter Baron and Thomas Klausner

    This file is part of ckmame, a program to check rom sets for MAME.
    The authors can be contacted at <ckmame@nih.at>

    Redistribution and use in source and binary forms, with or without
    modification, are permitted provided that the following conditions
    are met:
    1. Redistributions of source code must retain the above copyright
       notice, this list of conditions and the following disclaimer.
    2. Redistributions in binary form must reproduce the above copyright
       notice, this list of conditions and the following disclaimer in
       the documentation and/or other materials provided with the
       distribution.
    3. The name of the author may not be used to endorse or promote
       products derived from this software without specific prior
       written permission.

    THIS SOFTWARE IS PROVIDED BY THE AUTHORS ``AS IS'' AND ANY EXPRESS
    OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
    WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
    ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHORS BE LIABLE FOR ANY
    DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
    DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE
    GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
    INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER
    IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR
    OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN
    IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/

#ifndef MKMAMEDB_H
#define MKMAMEDB_H

#include "Command.h"
#include "OutputContext.h"
#include "Parser.h"

class MkMameDB : public Command {
  public:
    MkMameDB();

    void global_setup(const ParsedCommandline& commandline) override;
    bool execute(const std::vector<std::string>& arguments) override;
    bool global_cleanup() override;

  private:
    bool process_file(const std::string &fname, OutputContext *out);
    bool process_stdin(OutputContext *out);

    Parser::Options parser_options{{}};
    std::string dbname, dbname_real;
    std::unordered_set<std::string> exclude;
    std::vector<std::string> file_patterns;
    std::unordered_set<std::string> skip_files;
    DatEntry dat;
    int flags{0};
    OutputContext::Format fmt{OutputContext::FORMAT_DB};
    std::string detector_name;
    bool force{false};
    bool runtest{false};

    bool list_available_dats{false};
    bool list_dats{false};
};

#endif // MKMAMEDB_H
